package com.fastest.pass.login.di

import com.fastest.pass.login.data.remote.LoginApiService
import com.fastest.pass.login.data.repository.LoginRepositoryImpl
import com.fastest.pass.login.domain.repository.LoginRepository
import com.fastest.pass.login.utils.LoginNavigation
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.components.SingletonComponent
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import javax.inject.Singleton

@Module
@InstallIn(SingletonComponent::class)
object LoginModule {

    @Provides
    @Singleton
    fun provideNavigation(): LoginNavigation {
        return LoginNavigation()
    }

    @Provides
    @Singleton
    fun provideLoginApiService(): LoginApiService {
        return Retrofit.Builder()
            .baseUrl("https://api.fastestpass.com/v1/")
            .addConverterFactory(GsonConverterFactory.create())
            .build()
            .create(LoginApiService::class.java)
    }

    @Provides
    @Singleton
    fun provideLoginRepository(loginApiService: LoginApiService) : LoginRepository{
        return LoginRepositoryImpl(loginApiService)
    }
}